@@ -1,4 +1,4 @@
-# Copyright 2001-2005, Paul Johnson (pjcj@cpan.org)
+# Copyright 2001-2006, Paul Johnson (pjcj@cpan.org)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,13 +10,19 @@ package Devel::Cover::Report::Html_basic;
 use strict;
 use warnings;
 
-our $VERSION = "0.54";
+our $VERSION = "0.56";
 
-use Devel::Cover::DB 0.54;
+use Devel::Cover::DB 0.56;
 
 use Getopt::Long;
 use Template 2.00;
 
+my $HAVE_PPI;
+BEGIN {
+    eval "use PPI; use PPI::HTML;";
+    $HAVE_PPI = !$@;
+}
+
 my $Template;
 my %R;
 
@@ -84,7 +90,42 @@ sub print_summary
     my $html = "$R{options}{outputdir}/$R{options}{option}{outputfile}";
     $Template->process("summary", $vars, $html) or die $Template->error();
 
-    print "HTML output sent to $html\n";
+    $html
+}
+
+sub _highlight {
+    my @all_lines = @_;
+    my $code = join "", @all_lines;
+    my $document = PPI::Document->new(\$code);
+    my $highlight = PPI::HTML->new(line_numbers => 1);
+    my $pretty =  $highlight->html($document);
+
+    my $split = '<span class="line_number">';
+    
+    # turn significant whitespace into &nbsp;
+    @all_lines = map {
+        $_ =~ s{</span>( +)}{"</span>" . ("&nbsp;" x length($1))}e;
+        "$split$_";
+    } split /$split/, $pretty;
+    
+    # remove the line number
+    @all_lines = map {
+        s{<span class="line_number">.*?</span>}{}; $_;
+    } @all_lines;
+    @all_lines = map {
+        s{<span class="line_number">}{}; $_;
+    } @all_lines;
+    
+    # remove the BR
+    @all_lines = map {
+        s{<br>$}{}; $_;
+    } @all_lines;
+    @all_lines = map {
+        s{<br>\n</span>}{</span>}; $_;
+    } @all_lines;
+    
+    shift @all_lines if $all_lines[0] eq "";
+    return @all_lines;
 }
 
 sub print_file
@@ -92,10 +133,15 @@ sub print_file
     my @lines;
     my $f = $R{db}->cover->file($R{file});
 
-    open F, $R{file} or warn("Unable to open $R{file}: $!\n"), next;
-    LINE: while (defined(my $l = <F>))
+    open F, $R{file} or warn("Unable to open $R{file}: $!\n"), return;
+    my @all_lines = <F>;
+
+    @all_lines = _highlight(@all_lines) if $HAVE_PPI;
+    
+    my $linen = 1;
+    LINE: while (defined(my $l = shift @all_lines))
     {
-        my $n = $.;
+        my $n  = $linen++;
         chomp $l;
 
         my %criteria;
@@ -126,7 +172,7 @@ sub print_file
                 for my $a (0 .. $ann->count - 1)
                 {
                     my $text = $ann->text ($R{file}, $n, $a);
-                    $text = "&nbsp;" unless length $text;
+                    $text = "&nbsp;" unless $text && length $text;
                     push @{$line{criteria}},
                     {
                         text  => $text,
@@ -180,6 +226,9 @@ sub print_branches
         for my $b (@{$branches->location($location)})
         {
             $count++;
+            my $text = $b->text;
+            ($text) = _highlight($text) if $HAVE_PPI;
+
             push @branches,
                 {
                     number     => $count == 1 ? $location : "",
@@ -190,7 +239,7 @@ sub print_branches
                                              "branch") },
                             0 .. $b->total - 1
                     ],
-                    text       => $b->text,
+                    text       => $text,
                 };
         }
     }
@@ -218,6 +267,9 @@ sub print_conditions
         {
             $count{$c->type}++;
             # print "-- [$count{$c->type}][@{[$c->text]}]}]\n";
+            my $text = $c->text;
+            ($text) = _highlight($text) if $HAVE_PPI;
+
             push @{$r{$c->type}},
                 {
                     number     => $count{$c->type} == 1 ? $location : "",
@@ -229,7 +281,7 @@ sub print_conditions
                                              "condition") },
                             0 .. $c->total - 1
                     ],
-                    text       => $c->text,
+                    text       => $text,
                 };
         }
     }
@@ -346,7 +398,7 @@ sub report
     );
 
     print_stylesheet;
-    print_summary;
+    my $html = print_summary;
 
     for (@{$options->{file}})
     {
@@ -357,6 +409,8 @@ sub report
         print_conditions  if $show->{condition};
         print_subroutines if $show->{subroutine} || $show->{pod};
     }
+
+    print "HTML output sent to $html\n";
 }
 
 1;
@@ -366,7 +420,7 @@ package Devel::Cover::Report::Html_basic::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = "0.54";
+our $VERSION = "0.56";
 
 use base "Template::Provider";
 
@@ -381,23 +435,17 @@ sub fetch
 }
 
 $Templates{html} = <<'EOT';
+<?xml version="1.0" encoding="utf-8"?>
 <!--
-
-This file was generated by Devel::Cover Version 0.54
-
-Devel::Cover is copyright 2001-2002, Paul Johnson (pjcj@cpan.org)
-
-Devel::Cover is free.  It is licensed under the same terms as Perl itself.
-
+This file was generated by Devel::Cover Version 0.56
+Devel::Cover is copyright 2001-2006, Paul Johnson (pjcj\@cpan.org)
+Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
 http://www.pjcj.net
-
 -->
-
-<?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE html
-    PUBLIC "-//W3C//DTD XHTML Basic 1.0//EN"
-    "http://www.w3.org/TR/xhtml-basic/xhtml-basic10.dtd">
+     PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
+     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
     <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1"></meta>
@@ -414,7 +462,7 @@ EOT
 $Templates{header} = <<'EOT';
 <table>
     <tr>
-        <th colspan=4>[% R.file %]</th>
+        <th colspan="4">[% R.file %]</th>
     </tr>
     <tr class="hblank"><td class="dblank"></td></tr>
     <tr>
@@ -429,7 +477,7 @@ $Templates{header} = <<'EOT';
             <td class="h">[% criterion %]</td>
             <td>[% vals.covered %]</td>
             <td>[% vals.total %]</td>
-            <td class="[% vals.class %]" title="[% vals.details %]">
+            <td [% IF vals.class %]class="[% vals.class %]" [% END %]title="[% vals.details %]">
                 [% IF vals.link.defined %]
                     <a href="[% vals.link %]"> [% vals.pc %] </a>
                 [% ELSE %]
@@ -523,7 +571,9 @@ $Templates{file} = <<'EOT';
 
     [% FOREACH line = lines %]
         <tr>
-            <td [% IF line.number %] class="h" [% END %]>[% line.number %]</td>
+            <td [% IF line.number %] class="h" [% END %]>
+                <a [% IF line.number != '&nbsp;' %]name="[% line.number %]"[% END %]>[% line.number %]</a>
+            </td>
             [% FOREACH cr = line.criteria %]
                 <td [% IF cr.class %] class="[% cr.class %]" [% END %]>
                     [% IF cr.link.defined %] <a href="[% cr.link %]"> [% END %]
@@ -663,7 +713,8 @@ statistics
 =head1 DESCRIPTION
 
 This module provides a HTML reporting mechanism for coverage data.  It
-is designed to be called from the C<cover> program.
+is designed to be called from the C<cover> program. It will add syntax
+highlighting if PPI::HTML is installed.
 
 =head1 SEE ALSO
 
@@ -675,11 +726,11 @@ Huh?
 
 =head1 VERSION
 
-Version 0.54 - 13th September 2005
+Version 0.56 - 1st August 2006
 
 =head1 LICENCE
 
-Copyright 2001-2005, Paul Johnson (pjcj@cpan.org)
+Copyright 2001-2006, Paul Johnson (pjcj@cpan.org)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -763,6 +814,7 @@ pre,.s {
  *   c2  : coverage >= 90%
  *   c3  : path covered or coverage = 100%
  */
+ c0, .c1, .c2, .c3 { text-align: right; }
 .c0 {
     background-color: #ff9999;
     border: solid 1px #cc0000;
@@ -779,3 +831,19 @@ pre,.s {
     background-color: #99ff99;
     border: solid 1px #009900;
 }
+
+/* For syntax highlighting with PPI::HTML */
+.line_number { color: #aaaaaa; }
+.comment  { color: #228B22; }
+.symbol  { color: #00688B; }
+.word { color: #8B008B; font-weight:bold; }
+.pragma { color: #8B008B; font-weight:bold; }
+.structure { color: #000000; }
+.number { color: #B452CD; }
+.single  { color: #CD5555;}
+.double  { color: #CD5555;}
+.match   { color: #CD5555;}
+.substitute { color: #CD5555;}
+.heredoc_content { color: #CD5555;}
+.interpolate { color: #CD5555;}
+.words { color: #CD5555;}
