@@ -4,10 +4,10 @@ use strict;
 use warnings;
 use CGI;
 use Getopt::Long;
-use Devel::Cover::DB 0.54;
-use Devel::Cover::Truth_Table 0.54;
+use Devel::Cover::DB 0.56;
+use Devel::Cover::Truth_Table 0.56;
 
-our $VERSION = "0.54";
+our $VERSION = "0.56";
 
 #-------------------------------------------------------------------------------
 # Subroutine : get_coverage_for_line
@@ -256,15 +256,14 @@ sub print_html_header {
     my $title = shift;
 
     print $fh <<"END_HTML";
+<?xml version="1.0" encoding="utf-8"?>
 <!--
-This file was generated by Devel::Cover Version 0.54
-Devel::Cover is copyright 2001-2004, Paul Johnson (pjcj\@cpan.org)
+This file was generated by Devel::Cover Version 0.56
+Devel::Cover is copyright 2001-2006, Paul Johnson (pjcj\@cpan.org)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
 http://www.pjcj.net
 -->
-
-<?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML Basic 1.0//EN"
     "http://www.w3.org/TR/xhtml-basic/xhtml-basic10.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
@@ -733,7 +732,7 @@ Carman (mjcarman@mchsi.com).
 
 =head1 OPTIONS
 
-Options are specified by adding the appropraite flags to the C<cover> program.
+Options are specified by adding the appropriate flags to the C<cover> program.
 This report format supports the following:
 
 =over 4
@@ -775,11 +774,11 @@ Devel::Cover
 
 =head1 VERSION
 
-Version 0.54 - 13th September 2005
+Version 0.56 - 1st August 2006
 
 =head1 LICENCE
 
-Copyright 2001-2005, Paul Johnson (pjcj@cpan.org)
+Copyright 2001-2006, Paul Johnson (pjcj@cpan.org)
 
 This software is free. It is licensed under the same terms as Perl itself.
 
@@ -849,6 +848,7 @@ pre,.s {
  *   c2  : coverage >= 90%
  *   c3  : path covered or coverage = 100%
  */
+.c0, .c1, .c2, .c3 { text-align: right; }
 .c0 {
 	background-color: #ff9999;
 	border: solid 1px #cc0000;
